[![PyPi](https://img.shields.io/pypi/v/autolab)](https://pypi.org/project/autolab/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/autolab)
[![PyPI Downloads](https://img.shields.io/pypi/dm/autolab.svg?label=PyPI%20downloads)](https://pypi.org/project/autolab/)

[![Documentation Status](https://readthedocs.org/projects/autolab/badge/?version=latest)](https://autolab.readthedocs.io/en/latest/?badge=latest)

# Autolab
__Python package for scientific experiments automation__

The purpose of this package it to provide easy and efficient tools to deal with your scientific instruments, and to run automated experiments with them, by command line instructions or through a graphical user interface (GUI).

Created by Quentin Chateiller, Python drivers originally from Quentin Chateiller and Bruno Garbin, for the C2N-CNRS (Center for Nanosciences and Nanotechnologies, Palaiseau, France) ToniQ team.
Project continued by Jonathan Peltier, for the C2N-CNRS Minaphot team and Mathieu Jeannin, for the C2N-CNRS Odin team.

Project hosted at https://github.com/autolab-project/autolab

Drivers made for this package can be found at https://github.com/autolab-project/autolab-drivers

Visit https://autolab.readthedocs.io/ for the full documentation of this package.

## Overview

<img src="https://raw.githubusercontent.com/autolab-project/autolab/master/docs/scheme.png">

## GUI example

<img src="https://raw.githubusercontent.com/autolab-project/autolab/master/docs/gui/scanning.png">

<img src="https://raw.githubusercontent.com/autolab-project/autolab/master/docs/gui/control_panel.png">
